#[track]Expand description
Fetches the issue from Github and emits a warning or error if it is closed depending on the
ISSUE_HARD_FAIL environment variable.
#[track]Fetches the issue from Github and emits a warning or error if it is closed depending on the
ISSUE_HARD_FAIL environment variable.